@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "php-mode" "1.27.0"
+(define-package "php-mode" "20250602.1308"
   "Major mode for editing PHP code."
   '((emacs "27.1"))
   :url "https://github.com/emacs-php/php-mode"
-  :commit "c3fa4e020cdb631743dbb7b6007ea546a8db1f34"
-  :revdesc "c3fa4e020cdb"
+  :commit "40b8abed3079771e060dd99a56703520dabf5be4"
+  :revdesc "40b8abed3079"
   :keywords '("languages" "php")
   :maintainers '(("USAMI Kenta" . "tadsan@zonu.me")))
